@@ -33,9 +33,10 @@
 #  define KGLOBALACCEL_DEPRECATED_NO_EXPORT KGLOBALACCEL_NO_EXPORT KGLOBALACCEL_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KGLOBALACCEL_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KGLOBALACCEL_NO_DEPRECATED
+#    define KGLOBALACCEL_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
