@@ -33,9 +33,10 @@
 #  define KF5GLOBALACCELPRIVATE_DEPRECATED_NO_EXPORT KF5GLOBALACCELPRIVATE_NO_EXPORT KF5GLOBALACCELPRIVATE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KF5GLOBALACCELPRIVATE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KF5GLOBALACCELPRIVATE_NO_DEPRECATED
+#    define KF5GLOBALACCELPRIVATE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
